=============================
PyDy Package's documentation!
=============================

This is the central page for all PyDy's Documentation.

.. include:: ../README.rst

codegen package
---------------

.. toctree::
    :maxdepth: 2

    codegen/api.rst

viz package
-----------

.. toctree::
    :maxdepth: 2

    viz/introduction.rst
    viz/api.rst

Questions
=========

If you have any question about installation, or any general question, feel free
to visit the IRC channel at irc.freenode.net, channel `#pydy`_.  In addition,
our `mailing list`_ is an excellent source of community support.

If you think there’s a bug or you would like to request a feature, please open
an `issue`_.

.. _issue: https://github.com/PythonDynamics/pydy-viz/issues
.. _mailing list: http://groups.google.com/group/pydy
.. _#pydy: irc://irc.freenode.net/pydy

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
